@@ -6,6 +6,10 @@
 #include "AdvNeutronMonitorDNA.hh"
 
 AdvNeutronMonitorDNA:: AdvNeutronMonitorDNA(void){
+  if (!(isReady())) {
+    UtsusemiError("AdvNeutronMonitorDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
         //std::string filepath = getenv("HOME");
         std::string filepath = UtsusemiEnvGetUserDir();
         std::string filename = "monitor_data.dat";
@@ -34,6 +38,10 @@ AdvNeutronMonitorDNA:: AdvNeutronMonitorDNA(void){
 }
 
 AdvNeutronMonitorDNA:: AdvNeutronMonitorDNA(std::string filepath){
+  if (!(isReady())) {
+    UtsusemiError("AdvNeutronMonitorDNA >> Error Initializing (Maybe not found atomic data file).");
+    return;
+  }
        filename = filepath;
 
   wallInfo.initialize();
