@@ -1401,12 +1401,12 @@ def ILambdaCorrDNA(dat,ec,useMonEff):
     if filepath=="":
         raise UserWarning( "ILambdaCorrDNA >>> not found setup/monitor_data.dat " )
     CORR1 = md.AdvILambdaCorrectionDNA()
-    print("#[inamura 190322] ILambdaCorrDNA step 1")
     #ECM = CORR1.ILCorrection(dat,ec,useMonEff,filepath)
     ECM = mm.ElementContainerMatrix()
     ret = CORR1.ILCorrection(ECM,dat,ec,useMonEff,filepath)
+    if not ret:
+        raise UserWarning("ILambdaCorrDNA : Error >> check logs on a terminal window")
     del dat
-    print("#[inamura 190322] ILambdaCorrDNA fin")
     return ECM
 
 
